@@ -22,7 +22,18 @@ class StepMetadata:
         the specific parameters objectId=a.
         An action_list of None or an empty list means that all actions will
         be available for the next step.
-        Derived from GoalMetadata.action_list.
+
+        To "step" using the first action from the action_list:
+
+        .. highlight:: python
+        .. code-block:: python
+
+            step_metadata = controller.start_scene(scene_data)
+            action, params = step_metadata.action_list[0]
+            step_metadata = controller.step(action, **params)
+
+        Derived from :mod:`GoalMetadata.action_list[step_number]
+        <machine_common_sense.GoalMetadata>`.
         May be a subset of all possible actions. See
         :mod:`Action <machine_common_sense.Action>`.
     camera_aspect_ratio : (float, float)
@@ -174,7 +185,7 @@ class StepMetadata:
         if obj_list is None:
             return None
         else:
-            return dict((obj.uuid, dict(obj)) for obj in obj_list)
+            return {obj.uuid: dict(obj) for obj in obj_list}
 
     def copy_without_depth_or_images(self):
         """Return a deep copy of this StepMetadata with default depth_map_list,
