@@ -8,7 +8,6 @@ class TestObjectMetadata(unittest.TestCase):
 
     str_output = '''    {
         "uuid": "",
-        "color": {},
         "dimensions": [],
         "direction": {},
         "distance": -1.0,
@@ -19,6 +18,7 @@ class TestObjectMetadata(unittest.TestCase):
         "material_list": [],
         "position": {},
         "rotation": {},
+        "segment_color": {},
         "shape": "",
         "state_list": [],
         "texture_color_list": [],
@@ -40,10 +40,6 @@ class TestObjectMetadata(unittest.TestCase):
         self.assertEqual(self.object_metadata.uuid, "")
         self.assertIsInstance(self.object_metadata.uuid, str)
 
-    def test_color(self):
-        self.assertFalse(self.object_metadata.color)
-        self.assertIsInstance(self.object_metadata.color, dict)
-
     def test_dimensions(self):
         self.assertFalse(self.object_metadata.dimensions)
         self.assertIsInstance(self.object_metadata.dimensions, list)
@@ -84,6 +80,10 @@ class TestObjectMetadata(unittest.TestCase):
         self.assertFalse(self.object_metadata.rotation)
         self.assertIsInstance(self.object_metadata.rotation, dict)
 
+    def test_segment_color(self):
+        self.assertFalse(self.object_metadata.segment_color)
+        self.assertIsInstance(self.object_metadata.segment_color, dict)
+
     def test_shape(self):
         self.assertEqual(self.object_metadata.shape, "")
         self.assertIsInstance(self.object_metadata.shape, str)
